AcknowledgeJobOutput class

Represents the output of an AcknowledgeJob action.

Constructors

AcknowledgeJobOutput({JobStatus? status})
AcknowledgeJobOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → JobStatus?
Whether the job worker has received the specified job.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited