ActionConfigurationProperty class

Represents information about an action configuration property.

Constructors

ActionConfigurationProperty({required bool key, required String name, required bool required, required bool secret, String? description, bool? queryable, ActionConfigurationPropertyType? type})
ActionConfigurationProperty.fromJson(Map<String, dynamic> json)
factory

Properties

description → String?
The description of the action configuration property that is displayed to users.
final
hashCode → int
The hash code for this object.
no setterinherited
key → bool
Whether the configuration property is a key.
final
name → String
The name of the action configuration property.
final
queryable → bool?
Indicates that the property is used with PollForJobs. When creating a custom action, an action can have up to one queryable property. If it has one, that property must be both required and not secret.
final
required → bool
Whether the configuration property is a required value.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secret → bool
Whether the configuration property is secret. Secrets are hidden from all calls except for GetJobDetails, GetThirdPartyJobDetails, PollForJobs, and PollForThirdPartyJobs.
final
type → ActionConfigurationPropertyType?
The type of the configuration property.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited