ActionContext class

Represents the context of an action in the stage of a pipeline to a job worker.

Constructors

ActionContext({String? actionExecutionId, String? name})
ActionContext.fromJson(Map<String, dynamic> json)
factory

Properties

actionExecutionId → String?
The system-generated unique ID that corresponds to an action's execution.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the action in the context of a job.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited