ActionExecutionInput class

Input information used for an action execution.

Constructors

ActionExecutionInput({ActionTypeId? actionTypeId, Map<String, String>? configuration, List<ArtifactDetail>? inputArtifacts, String? namespace, String? region, Map<String, String>? resolvedConfiguration, String? roleArn})
ActionExecutionInput.fromJson(Map<String, dynamic> json)
factory

Properties

actionTypeId → ActionTypeId?
final
configuration → Map<String, String>?
Configuration data for an action execution.
final
hashCode → int
The hash code for this object.
no setterinherited
inputArtifacts → List<ArtifactDetail>?
Details of input artifacts of the action that correspond to the action execution.
final
namespace → String?
The variable namespace associated with the action. All variables produced as output by this action fall under this namespace.
final
region → String?
The AWS Region for the action, such as us-east-1.
final
resolvedConfiguration → Map<String, String>?
Configuration data for an action execution with all variable references replaced with their real values for the execution.
final
roleArn → String?
The ARN of the IAM service role that performs the declared action. This is assumed through the roleArn for the pipeline.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited