ActionType class

Returns information about the details of an action type.

Constructors

ActionType({required ActionTypeId id, required ArtifactDetails inputArtifactDetails, required ArtifactDetails outputArtifactDetails, List<ActionConfigurationProperty>? actionConfigurationProperties, ActionTypeSettings? settings})
ActionType.fromJson(Map<String, dynamic> json)
factory

Properties

actionConfigurationProperties → List<ActionConfigurationProperty>?
The configuration properties for the action type.
final
hashCode → int
The hash code for this object.
no setterinherited
id → ActionTypeId
Represents information about an action type.
final
inputArtifactDetails → ArtifactDetails
The details of the input artifact for the action, such as its commit ID.
final
outputArtifactDetails → ArtifactDetails
The details of the output artifact of the action, such as its commit ID.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → ActionTypeSettings?
The settings for the action type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited