CreateCustomActionTypeOutput class

Represents the output of a CreateCustomActionType operation.

Constructors

CreateCustomActionTypeOutput({required ActionType actionType, List<Tag>? tags})
CreateCustomActionTypeOutput.fromJson(Map<String, dynamic> json)
factory

Properties

actionType → ActionType
Returns information about the details of an action type.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
Specifies the tags applied to the custom action.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited