CreatePipelineOutput class

Represents the output of a CreatePipeline action.

Constructors

CreatePipelineOutput({PipelineDeclaration? pipeline, List<Tag>? tags})
CreatePipelineOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pipeline → PipelineDeclaration?
Represents the structure of actions and stages to be performed in the pipeline.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
Specifies the tags applied to the pipeline.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited