CurrentRevision class

Represents information about a current revision.

Constructors

CurrentRevision({required String changeIdentifier, required String revision, DateTime? created, String? revisionSummary})

Properties

changeIdentifier → String
The change identifier for the current revision.
final
created → DateTime?
The date and time when the most recent revision of the artifact was created, in timestamp format.
final
hashCode → int
The hash code for this object.
no setterinherited
revision → String
The revision ID of the current version of an artifact.
final
revisionSummary → String?
The summary of the most recent revision of the artifact.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited