EncryptionKey class

Represents information about the key used to encrypt data in the artifact store, such as an AWS Key Management Service (AWS KMS) key.

Constructors

EncryptionKey({required String id, required EncryptionKeyType type})
EncryptionKey.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
The ID used to identify the key. For an AWS KMS key, you can use the key ID, the key ARN, or the alias ARN.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → EncryptionKeyType
The type of encryption key, such as an AWS Key Management Service (AWS KMS) key. When creating or updating a pipeline, the value must be set to 'KMS'.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited