ExecutionTrigger class

The interaction or event that started a pipeline execution.

Constructors

ExecutionTrigger({String? triggerDetail, TriggerType? triggerType})
ExecutionTrigger.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggerDetail → String?
Detail related to the event that started a pipeline execution, such as the webhook ARN of the webhook that triggered the pipeline execution or the user ARN for a user-initiated start-pipeline-execution CLI command.
final
triggerType → TriggerType?
The type of change-detection method, command, or user interaction that started a pipeline execution.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited