GetPipelineStateOutput class

Represents the output of a GetPipelineState action.

Constructors

GetPipelineStateOutput({DateTime? created, String? pipelineName, int? pipelineVersion, List<StageState>? stageStates, DateTime? updated})
GetPipelineStateOutput.fromJson(Map<String, dynamic> json)
factory

Properties

created → DateTime?
The date and time the pipeline was created, in timestamp format.
final
hashCode → int
The hash code for this object.
no setterinherited
pipelineName → String?
The name of the pipeline for which you want to get the state.
final
pipelineVersion → int?
The version number of the pipeline.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stageStates → List<StageState>?
A list of the pipeline stage output information, including stage name, state, most recent run details, whether the stage is disabled, and other data.
final
updated → DateTime?
The date and time the pipeline was last updated, in timestamp format.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited