Job class

Represents information about a job.

Constructors

Job({String? accountId, JobData? data, String? id, String? nonce})
Job.fromJson(Map<String, dynamic> json)
factory

Properties

accountId → String?
The ID of the AWS account to use when performing the job.
final
data → JobData?
Other data about a job.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The unique system-generated ID of the job.
final
nonce → String?
A system-generated random number that AWS CodePipeline uses to ensure that the job is being worked on by only one job worker. Use this number in an AcknowledgeJob request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited