JobData class

Represents other information about a job required for a job worker to complete the job.

Constructors

JobData({ActionConfiguration? actionConfiguration, ActionTypeId? actionTypeId, AWSSessionCredentials? artifactCredentials, String? continuationToken, EncryptionKey? encryptionKey, List<Artifact>? inputArtifacts, List<Artifact>? outputArtifacts, PipelineContext? pipelineContext})
JobData.fromJson(Map<String, dynamic> json)
factory

Properties

actionConfiguration → ActionConfiguration?
Represents information about an action configuration.
final
actionTypeId → ActionTypeId?
Represents information about an action type.
final
artifactCredentials → AWSSessionCredentials?
Represents an AWS session credentials object. These credentials are temporary credentials that are issued by AWS Secure Token Service (STS). They can be used to access input and output artifacts in the S3 bucket used to store artifacts for the pipeline in AWS CodePipeline.
final
continuationToken → String?
A system-generated token, such as a AWS CodeDeploy deployment ID, required by a job to continue the job asynchronously.
final
encryptionKey → EncryptionKey?
Represents information about the key used to encrypt data in the artifact store, such as an AWS Key Management Service (AWS KMS) key.
final
hashCode → int
The hash code for this object.
no setterinherited
inputArtifacts → List<Artifact>?
The artifact supplied to the job.
final
outputArtifacts → List<Artifact>?
The output of the job.
final
pipelineContext → PipelineContext?
Represents information about a pipeline to a job worker.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited