ListActionExecutionsOutput class

Constructors

ListActionExecutionsOutput({List<ActionExecutionDetail>? actionExecutionDetails, String? nextToken})
ListActionExecutionsOutput.fromJson(Map<String, dynamic> json)
factory

Properties

actionExecutionDetails → List<ActionExecutionDetail>?
The details for a list of recent executions, such as action execution ID.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
If the amount of returned information is significantly large, an identifier is also returned and can be used in a subsequent ListActionExecutions call to return the next set of action executions in the list.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited