ListWebhookItem class

The detail returned for each webhook after listing webhooks, such as the webhook URL, the webhook name, and the webhook ARN.

Constructors

ListWebhookItem({required WebhookDefinition definition, required String url, String? arn, String? errorCode, String? errorMessage, DateTime? lastTriggered, List<Tag>? tags})
ListWebhookItem.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The Amazon Resource Name (ARN) of the webhook.
final
definition → WebhookDefinition
The detail returned for each webhook, such as the webhook authentication type and filter rules.
final
errorCode → String?
The number code of the error.
final
errorMessage → String?
The text of the error message about the webhook.
final
hashCode → int
The hash code for this object.
no setterinherited
lastTriggered → DateTime?
The date and time a webhook was last successfully triggered, in timestamp format.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<Tag>?
Specifies the tags applied to the webhook.
final
url → String
A unique URL generated by CodePipeline. When a POST request is made to this URL, the defined pipeline is started as long as the body of the post request satisfies the defined authentication and filtering conditions. Deleting and re-creating a webhook makes the old URL invalid and generates a new one.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited