ListWebhooksOutput class

Constructors

ListWebhooksOutput({String? nextToken, List<ListWebhookItem>? webhooks})
ListWebhooksOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
If the amount of returned information is significantly large, an identifier is also returned and can be used in a subsequent ListWebhooks call to return the next set of webhooks in the list.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webhooks → List<ListWebhookItem>?
The JSON detail returned for each webhook in the list output for the ListWebhooks call.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited