SourceRevision class

Information about the version (or revision) of a source artifact that initiated a pipeline execution.

Constructors

SourceRevision({required String actionName, String? revisionId, String? revisionSummary, String? revisionUrl})
SourceRevision.fromJson(Map<String, dynamic> json)
factory

Properties

actionName → String
The name of the action that processed the revision to the source artifact.
final
hashCode → int
The hash code for this object.
no setterinherited
revisionId → String?
The system-generated unique ID that identifies the revision number of the artifact.
final
revisionSummary → String?
Summary information about the most recent revision of the artifact. For GitHub and AWS CodeCommit repositories, the commit message. For Amazon S3 buckets or actions, the user-provided content of a codepipeline-artifact-revision-summary key specified in the object metadata.
final
revisionUrl → String?
The commit ID for the artifact revision. For artifacts stored in GitHub or AWS CodeCommit repositories, the commit ID is linked to a commit details page.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited