StageDeclaration class

Represents information about a stage and its definition.

Constructors

StageDeclaration({required List<ActionDeclaration> actions, required String name, List<BlockerDeclaration>? blockers})
StageDeclaration.fromJson(Map<String, dynamic> json)
factory

Properties

actions → List<ActionDeclaration>
The actions included in a stage.
final
blockers → List<BlockerDeclaration>?
Reserved for future use.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the stage.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited