StageState class

Represents information about the state of the stage.

Constructors

StageState({List<ActionState>? actionStates, StageExecution? inboundExecution, TransitionState? inboundTransitionState, StageExecution? latestExecution, String? stageName})
StageState.fromJson(Map<String, dynamic> json)
factory

Properties

actionStates → List<ActionState>?
The state of the stage.
final
hashCode → int
The hash code for this object.
no setterinherited
inboundExecution → StageExecution?
final
inboundTransitionState → TransitionState?
The state of the inbound transition, which is either enabled or disabled.
final
latestExecution → StageExecution?
Information about the latest execution in the stage, including its ID and status.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stageName → String?
The name of the stage.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited