TransitionState class

Represents information about the state of transitions between one stage and another stage.

Constructors

TransitionState({String? disabledReason, bool? enabled, DateTime? lastChangedAt, String? lastChangedBy})
TransitionState.fromJson(Map<String, dynamic> json)
factory

Properties

disabledReason → String?
The user-specified reason why the transition between two stages of a pipeline was disabled.
final
enabled → bool?
Whether the transition between stages is enabled (true) or disabled (false).
final
hashCode → int
The hash code for this object.
no setterinherited
lastChangedAt → DateTime?
The timestamp when the transition state was last changed.
final
lastChangedBy → String?
The ID of the user who last changed the transition state.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited