WebhookAuthConfiguration class

The authentication applied to incoming webhook trigger requests.

Constructors

WebhookAuthConfiguration({String? allowedIPRange, String? secretToken})
WebhookAuthConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

allowedIPRange → String?
The property used to configure acceptance of webhooks in an IP address range. For IP, only the AllowedIPRange property must be set. This property must be set to a valid CIDR range.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretToken → String?
The property used to configure GitHub authentication. For GITHUB_HMAC, only the SecretToken property must be set.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited