WebhookDefinition class

Represents information about a webhook and its definition.

Constructors

WebhookDefinition({required WebhookAuthenticationType authentication, required WebhookAuthConfiguration authenticationConfiguration, required List<WebhookFilterRule> filters, required String name, required String targetAction, required String targetPipeline})
WebhookDefinition.fromJson(Map<String, dynamic> json)
factory

Properties

authentication → WebhookAuthenticationType
Supported options are GITHUB_HMAC, IP, and UNAUTHENTICATED.
final
authenticationConfiguration → WebhookAuthConfiguration
Properties that configure the authentication applied to incoming webhook trigger requests. The required properties depend on the authentication type. For GITHUB_HMAC, only the SecretToken property must be set. For IP, only the AllowedIPRange property must be set to a valid CIDR range. For UNAUTHENTICATED, no properties can be set.
final
filters → List<WebhookFilterRule>
A list of rules applied to the body/payload sent in the POST request to a webhook URL. All defined rules must pass for the request to be accepted and the pipeline started.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the webhook.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetAction → String
The name of the action in a pipeline you want to connect to the webhook. The action must be from the source (first) stage of the pipeline.
final
targetPipeline → String
The name of the pipeline you want to connect to the webhook.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited